tokenisers - MultiMolecule
Author: MultiMolecule
Description: Neural Networks for RNA, DNA, and Protein

跳转至

# tokenisers

`tokenisers` 提供了一系列预定义令牌器。

令牌器是一个将核苷酸或氨基酸序列转换为索引序列的类。它用于在将输入序列馈送到模型之前对其进行预处理。

请参阅 Tokenizer 了解更多细节。

## 可用令牌器

- DnaTokenizer
- RnaTokenizer
- ProteinTokenizer

2024-07-10 01:11:47

#### Cookie Consent

We use cookies to recognize your repeated visits and preferences, as well as to measure the effectiveness of our documentation and whether users find what they're searching for. With your consent, you're helping us to make our documentation better. Please check out our Privacy Notice for more information.

- Google Analytics
- GitHub

管理设定